.. _fragment:

Fragments
=========

.. sectionauthor:: Matt Swain <m.swain@me.com>

This page gives details on dealing with fragments.

The term fragment refers to covalently bonded units. A molecule can contain multiple fragments.


Getting the largest fragment
----------------------------

- LargestFragmentChooser

Filtering out fragments
-----------------------

- FragmentRemover
